summaryrefslogtreecommitdiffstats
path: root/src/compiler/blob.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/compiler/blob.h')
-rw-r--r--src/compiler/blob.h13
1 files changed, 5 insertions, 8 deletions
diff --git a/src/compiler/blob.h b/src/compiler/blob.h
index 4cbbb01b15d..8a7a28b4f3c 100644
--- a/src/compiler/blob.h
+++ b/src/compiler/blob.h
@@ -79,21 +79,18 @@ struct blob_reader {
};
/**
- * Create a new, empty blob.
- *
- * \return The new blob, (or NULL in case of allocation failure).
+ * Init a new, empty blob.
*/
-struct blob *
-blob_create(void);
+void
+blob_init(struct blob *blob);
/**
* Destroy a blob and free its memory.
*/
static inline void
-blob_destroy(struct blob *blob)
+blob_finish(struct blob *blob)
{
free(blob->data);
- free(blob);
}
/**
@@ -79,21 +79,18 @@ struct blob_reader {
/**
- * Destroy a blob and free its memory.
+ * Finish a blob and free its memory.
*/
static inline void